pub fn parse_region_code(input: &str) -> Option<RegionCode>Expand description
Parses a region subtag and normalizes alphabetic regions to uppercase.
pub fn parse_region_code(input: &str) -> Option<RegionCode>Parses a region subtag and normalizes alphabetic regions to uppercase.